---
title: "Tracking API Jobs"
sub_link: "polyaxon-tracking-api/jobs"
meta_title: "Tracking API Jobs - Polyaxon References"
meta_description: "Jobs tracking is a high-level API allowing data scientists to track information related to their jobs."
visibility: public
status: published
tags:
    - tracking
    - reference
    - polyaxon
    - client
    - sdk
    - job
sidebar: "polyaxon-tracking-api"
---

Jobs tracking is a high-level API allowing data scientists to track information related to their jobs.

This is only useful for jobs running in a Polyaxon deployment.

## Tracking

```python
from polyaxon_client.tracking import Job

job = Job()
```

### Get job info

Get information about the job, this value is also exposed as an env var `POLYAXON_JOB_INFO`.

```python
job.get_job_info()
```

    * project_name
    * job_name
    * project_uuid
    * job_uuid


## Get log level: 

If set on the polyaxonfile it will return the log level,
you can access this value by using this function `job.get_log_level`, 
this value is also exposed as an env var `POLYAXON_LOG_LEVEL`.

## Paths

Experiment running inside Polyaxon have some paths and other information exposed to them, to access information about a Polyaxon run:


### Get the outputs path: 

The outputs path generated by polyaxon for the job,
you can access this value by using this function:

```python
job.get_outputs_path()
```
 
this value is also exposed as an env var `POLYAXON_RUN_OUTPUTS_PATH`.

        `user/project/jobs/job/files`


### Get outputs refs paths: 

The references outputs paths requested by the user, the order follows the order specified by the user, 
you can access this value by calling this function:

```python
job.get_outputs_refs_paths()
```
 
this value is also exposed as an env var `POLYAXON_REFS_OUTPUTS_PATHS`.:

        {
            'jobs': [
                `user/project/job12/files`,
            ], 'experiments': [
                `user/project/group/experiment1/files`,
                `user/project/experiment100/files`
            ]
        }


### Get data paths: 

The data paths mounted for the job/experiment, you can access this value by using this function:

```python
job.get_data_paths()
```
 
this value is also exposed as an env var `POLYAXON_RUN_DATA_PATHS`:

        {
          'data1': '/data/1',
          'data-foo': '/data/foo',
        }

## Accessing the API

Since the experiment is running in-cluster, the tracking API knows how to instantiate a client, 
this client is used not only to log the previous information, 
but it could be used to access to much richer API.

```python
client = job.client
```

This client is authenticated with the current user, and gives scoped access to all accessible objects of the user.

Please look at [Polyaxon client](/references/polyaxon-client/) for more information.

