# pylint:disable=ungrouped-imports

from unittest.mock import patch

import pytest

from flaky import flaky

import auditor

from events.registry import archive as archives_events
from tests.test_auditor.utils import AuditorBaseTest


@pytest.mark.auditor_mark
class AuditorArchivesTest(AuditorBaseTest):
    """Testing subscribed events"""
    EVENTS = archives_events.EVENTS

    def setUp(self):
        super().setUp()
        self.tested_events = {
            archives_events.ARCHIVE_BUILD_JOBS_VIEWED,
            archives_events.ARCHIVE_JOBS_VIEWED,
            archives_events.ARCHIVE_EXPERIMENTS_VIEWED,
            archives_events.ARCHIVE_EXPERIMENT_GROUPS_VIEWED,
            archives_events.ARCHIVE_PROJECTS_VIEWED,
        }

    @flaky(max_runs=3)
    @patch('executor.executor_service.ExecutorService.record_event')
    @patch('notifier.service.NotifierService.record_event')
    @patch('tracker.service.TrackerService.record_event')
    @patch('activitylogs.service.ActivityLogService.record_event')
    def test_build_archives_viewed(self,
                                   activitylogs_record,
                                   tracker_record,
                                   notifier_record,
                                   executor_record):
        auditor.record(event_type=archives_events.ARCHIVE_BUILD_JOBS_VIEWED,
                       actor_id=1,
                       actor_name='foo',
                       id=2)

        assert tracker_record.call_count == 1
        assert activitylogs_record.call_count == 1
        assert notifier_record.call_count == 0
        assert executor_record.call_count == 0

    @patch('executor.executor_service.ExecutorService.record_event')
    @patch('notifier.service.NotifierService.record_event')
    @patch('tracker.service.TrackerService.record_event')
    @patch('activitylogs.service.ActivityLogService.record_event')
    def test_job_archives_viewed(self,
                                 activitylogs_record,
                                 tracker_record,
                                 notifier_record,
                                 executor_record):
        auditor.record(event_type=archives_events.ARCHIVE_JOBS_VIEWED,
                       actor_id=1,
                       actor_name='foo',
                       id=1)

        assert tracker_record.call_count == 1
        assert activitylogs_record.call_count == 1
        assert notifier_record.call_count == 0
        assert executor_record.call_count == 0

    @patch('executor.executor_service.ExecutorService.record_event')
    @patch('notifier.service.NotifierService.record_event')
    @patch('tracker.service.TrackerService.record_event')
    @patch('activitylogs.service.ActivityLogService.record_event')
    def test_experiment_archives_viewed(self,
                                        activitylogs_record,
                                        tracker_record,
                                        notifier_record,
                                        executor_record):
        auditor.record(event_type=archives_events.ARCHIVE_EXPERIMENTS_VIEWED,
                       actor_id=1,
                       actor_name='foo',
                       id=2)

        assert tracker_record.call_count == 1
        assert activitylogs_record.call_count == 1
        assert notifier_record.call_count == 0
        assert executor_record.call_count == 0

    @patch('executor.executor_service.ExecutorService.record_event')
    @patch('notifier.service.NotifierService.record_event')
    @patch('tracker.service.TrackerService.record_event')
    @patch('activitylogs.service.ActivityLogService.record_event')
    def test_experiment_group_archives_viewed(self,
                                              activitylogs_record,
                                              tracker_record,
                                              notifier_record,
                                              executor_record):
        auditor.record(event_type=archives_events.ARCHIVE_EXPERIMENT_GROUPS_VIEWED,
                       actor_id=1,
                       actor_name='foo',
                       id=2)

        assert tracker_record.call_count == 1
        assert activitylogs_record.call_count == 1
        assert notifier_record.call_count == 0
        assert executor_record.call_count == 0

    @patch('executor.executor_service.ExecutorService.record_event')
    @patch('notifier.service.NotifierService.record_event')
    @patch('tracker.service.TrackerService.record_event')
    @patch('activitylogs.service.ActivityLogService.record_event')
    def test_project_archives_viewed(self,
                                     activitylogs_record,
                                     tracker_record,
                                     notifier_record,
                                     executor_record):
        auditor.record(event_type=archives_events.ARCHIVE_PROJECTS_VIEWED,
                       actor_id=1,
                       actor_name='foo',
                       id=1)

        assert tracker_record.call_count == 1
        assert activitylogs_record.call_count == 1
        assert notifier_record.call_count == 0
        assert executor_record.call_count == 0


del AuditorBaseTest
